---
name: BehaviorUnderDiscussion
about: If the code raises a BehaviorUnderDiscussion error
title: "[BEHAVIOR]"
labels: discussion
assignees: mayou36
---

## Describe what happens

A description of what you do with zfit and where the error arose, if you know about it.

## StackTrace

Please include the stacktrace here

## Environment

Please fill in the relevant points (if possible).

-   zfit version:
-   Python version:
-   Are you using conda, pipenv, etc? :
-   Operating System:
-   Tensorflow version:

## Desired behavior

What would you expect to happen and why? Be aware that there are also many more usecases than your specific one, if you can think of where it would break, please include this here.
